@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2014 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2015 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -34,11 +34,11 @@
 **************************************************************************/
 
 /* We will be using the LZO1X-1 algorithm, so we have
- * to include <lzo1x.h>
+ * to include <lzo/lzo1x.h>
  */
 
-#include "lzo/lzoconf.h"
-#include "lzo/lzo1x.h"
+#include <lzo/lzoconf.h>
+#include <lzo/lzo1x.h>
 
 /* portability layer */
 static const char *progname = NULL;
@@ -78,7 +78,7 @@ int __lzo_cdecl_main main(int argc, char *argv[])
 
     printf("\nLZO real-time data compression library (v%s, %s).\n",
            lzo_version_string(), lzo_version_date());
-    printf("Copyright (C) 1996-2014 Markus Franz Xaver Johannes Oberhumer\nAll Rights Reserved.\n\n");
+    printf("Copyright (C) 1996-2015 Markus Franz Xaver Johannes Oberhumer\nAll Rights Reserved.\n\n");
 
 /*
  * Step 1: initialize the LZO library
